package com.persagy.dmp.rwd.edit.service;

import com.persagy.common.criteria.CriteriaExpressionParser;
import com.persagy.common.criteria.CriteriaUtils;
import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.web.MapResponse;
import com.persagy.common.web.PagedResponse;
import com.persagy.dmp.rwd.edit.entity.AdminUser;
import com.persagy.dmp.rwd.edit.entity.QAdminUser;
import com.persagy.dmp.rwd.edit.repository.AdminUserRepository;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import java.util.*;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
class AdminUserServiceTest {

    @Mock
    private AdminUserRepository mockAdminUserRepository;
    @Mock
    private CriteriaUtils mockCriteriaUtils;

    @InjectMocks
    private AdminUserService adminUserServiceUnderTest;

    @Test
    void testQuery() {
        // Setup
        final JacksonCriteria criteria = JacksonCriteria.newInstance();
        when(mockCriteriaUtils.query(eq(new QAdminUser("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Run the test
        final PagedResponse<AdminUser> result = adminUserServiceUnderTest.query(criteria);

        // Verify the results
    }

    @Test
    void testCreate() {
        // Setup
        final AdminUser param = new AdminUser();
        param.setId(0);
        param.setUsername("username");
        param.setPassword("password");
        param.setRealname("realname");
        param.setPhone("phone");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);

        when(mockAdminUserRepository.count()).thenReturn(0L);

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser = new AdminUser();
        adminUser.setId(0);
        adminUser.setUsername("username");
        adminUser.setPassword("password");
        adminUser.setRealname("realname");
        adminUser.setPhone("phone");
        adminUser.setRemark("remark");
        adminUser.setStatus(0);
        adminUser.setCreateUser(0);
        adminUser.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.create(param);

        // Verify the results
    }

    @Test
    void testUpdate() {
        // Setup
        final AdminUser param = new AdminUser();
        param.setId(0);
        param.setUsername("username");
        param.setPassword("password");
        param.setRealname("realname");
        param.setPhone("phone");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);

        // Configure AdminUserRepository.findById(...).
        final AdminUser adminUser1 = new AdminUser();
        adminUser1.setId(0);
        adminUser1.setUsername("username");
        adminUser1.setPassword("password");
        adminUser1.setRealname("realname");
        adminUser1.setPhone("phone");
        adminUser1.setRemark("remark");
        adminUser1.setStatus(0);
        adminUser1.setCreateUser(0);
        adminUser1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser1.setUpdateUser(0);
        final Optional<AdminUser> adminUser = Optional.of(adminUser1);
        when(mockAdminUserRepository.findById(0)).thenReturn(adminUser);

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser2 = new AdminUser();
        adminUser2.setId(0);
        adminUser2.setUsername("username");
        adminUser2.setPassword("password");
        adminUser2.setRealname("realname");
        adminUser2.setPhone("phone");
        adminUser2.setRemark("remark");
        adminUser2.setStatus(0);
        adminUser2.setCreateUser(0);
        adminUser2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser2.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser2);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testUpdate_AdminUserRepositoryFindByIdReturnsAbsent() {
        // Setup
        final AdminUser param = new AdminUser();
        param.setId(0);
        param.setUsername("username");
        param.setPassword("password");
        param.setRealname("realname");
        param.setPhone("phone");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);

        when(mockAdminUserRepository.findById(0)).thenReturn(Optional.empty());

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser = new AdminUser();
        adminUser.setId(0);
        adminUser.setUsername("username");
        adminUser.setPassword("password");
        adminUser.setRealname("realname");
        adminUser.setPhone("phone");
        adminUser.setRemark("remark");
        adminUser.setStatus(0);
        adminUser.setCreateUser(0);
        adminUser.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testDelete() {
        // Setup
        final AdminUser param = new AdminUser();
        param.setId(0);
        param.setUsername("username");
        param.setPassword("password");
        param.setRealname("realname");
        param.setPhone("phone");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);

        // Configure AdminUserRepository.findById(...).
        final AdminUser adminUser1 = new AdminUser();
        adminUser1.setId(0);
        adminUser1.setUsername("username");
        adminUser1.setPassword("password");
        adminUser1.setRealname("realname");
        adminUser1.setPhone("phone");
        adminUser1.setRemark("remark");
        adminUser1.setStatus(0);
        adminUser1.setCreateUser(0);
        adminUser1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser1.setUpdateUser(0);
        final Optional<AdminUser> adminUser = Optional.of(adminUser1);
        when(mockAdminUserRepository.findById(0)).thenReturn(adminUser);

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser2 = new AdminUser();
        adminUser2.setId(0);
        adminUser2.setUsername("username");
        adminUser2.setPassword("password");
        adminUser2.setRealname("realname");
        adminUser2.setPhone("phone");
        adminUser2.setRemark("remark");
        adminUser2.setStatus(0);
        adminUser2.setCreateUser(0);
        adminUser2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser2.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser2);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.delete(param);

        // Verify the results
    }

    @Test
    void testDelete_AdminUserRepositoryFindByIdReturnsAbsent() {
        // Setup
        final AdminUser param = new AdminUser();
        param.setId(0);
        param.setUsername("username");
        param.setPassword("password");
        param.setRealname("realname");
        param.setPhone("phone");
        param.setRemark("remark");
        param.setStatus(0);
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);

        when(mockAdminUserRepository.findById(0)).thenReturn(Optional.empty());

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser = new AdminUser();
        adminUser.setId(0);
        adminUser.setUsername("username");
        adminUser.setPassword("password");
        adminUser.setRealname("realname");
        adminUser.setPhone("phone");
        adminUser.setRemark("remark");
        adminUser.setStatus(0);
        adminUser.setCreateUser(0);
        adminUser.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.delete(param);

        // Verify the results
    }

    @Test
    void testChgpwd() {
        // Setup
        final Map<String, String> param = new HashMap<>();

        // Configure AdminUserRepository.findById(...).
        final AdminUser adminUser1 = new AdminUser();
        adminUser1.setId(0);
        adminUser1.setUsername("username");
        adminUser1.setPassword("password");
        adminUser1.setRealname("realname");
        adminUser1.setPhone("phone");
        adminUser1.setRemark("remark");
        adminUser1.setStatus(0);
        adminUser1.setCreateUser(0);
        adminUser1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser1.setUpdateUser(0);
        final Optional<AdminUser> adminUser = Optional.of(adminUser1);
        when(mockAdminUserRepository.findById(0)).thenReturn(adminUser);

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser2 = new AdminUser();
        adminUser2.setId(0);
        adminUser2.setUsername("username");
        adminUser2.setPassword("password");
        adminUser2.setRealname("realname");
        adminUser2.setPhone("phone");
        adminUser2.setRemark("remark");
        adminUser2.setStatus(0);
        adminUser2.setCreateUser(0);
        adminUser2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser2.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser2);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.chgpwd(param);

        // Verify the results
    }

    @Test
    void testChgpwd_AdminUserRepositoryFindByIdReturnsAbsent() {
        // Setup
        final Map<String, String> param = new HashMap<>();
        when(mockAdminUserRepository.findById(0)).thenReturn(Optional.empty());

        // Configure AdminUserRepository.save(...).
        final AdminUser adminUser = new AdminUser();
        adminUser.setId(0);
        adminUser.setUsername("username");
        adminUser.setPassword("password");
        adminUser.setRealname("realname");
        adminUser.setPhone("phone");
        adminUser.setRemark("remark");
        adminUser.setStatus(0);
        adminUser.setCreateUser(0);
        adminUser.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        adminUser.setUpdateUser(0);
        when(mockAdminUserRepository.save(any(AdminUser.class))).thenReturn(adminUser);

        // Run the test
        final MapResponse result = adminUserServiceUnderTest.chgpwd(param);

        // Verify the results
    }
}
