package com.persagy.dmp.rwd.edit.service;

import com.fasterxml.jackson.databind.node.JsonNodeFactory;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.common.criteria.CriteriaExpressionParser;
import com.persagy.common.criteria.CriteriaUtils;
import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.web.MapResponse;
import com.persagy.common.web.PagedResponse;
import com.persagy.dmp.rwd.edit.entity.QRwdeditRefType;
import com.persagy.dmp.rwd.edit.entity.RwdeditRefType;
import com.persagy.dmp.rwd.edit.entity.RwdeditRefTypeInfos;
import com.persagy.dmp.rwd.edit.model.RwdeditRefTypeModel;
import com.persagy.dmp.rwd.edit.repository.RwdeditRefTypeRepository;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import java.util.Arrays;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Optional;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
class RwdeditRefTypeServiceTest {

    @Mock
    private CriteriaUtils mockCriteriaUtils;
    @Mock
    private RwdeditRefTypeRepository mockRepository;

    @InjectMocks
    private RwdeditRefTypeService rwdeditRefTypeServiceUnderTest;

    @Test
    void testQuery() {
        // Setup
        final JacksonCriteria criteria = JacksonCriteria.newInstance();
        when(mockCriteriaUtils.query(eq(new QRwdeditRefType("variable")), any(CriteriaExpressionParser.class), any(JacksonCriteria.class))).thenReturn(new PagedResponse<>());

        // Run the test
        final PagedResponse<RwdeditRefTypeModel> result = rwdeditRefTypeServiceUnderTest.query(criteria);

        // Verify the results
    }

    @Test
    void testCreate() {
        // Setup
        final RwdeditRefTypeModel param = new RwdeditRefTypeModel();
        param.setRefKey("refKey");
        param.setName("name");
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setSeq(0);
        param.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setInfos(Arrays.asList(rwdeditRefTypeInfos));

        // Configure RwdeditRefTypeRepository.findById(...).
        final RwdeditRefType rwdeditRefType1 = new RwdeditRefType();
        rwdeditRefType1.setRefKey("refKey");
        rwdeditRefType1.setName("name");
        rwdeditRefType1.setCreateUser(0);
        rwdeditRefType1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setUpdateUser(0);
        rwdeditRefType1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setSeq(0);
        rwdeditRefType1.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos1 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos1.setRefKey("refKey");
        rwdeditRefTypeInfos1.setCode("code");
        rwdeditRefTypeInfos1.setName("name");
        rwdeditRefTypeInfos1.setParentCode("parentCode");
        rwdeditRefTypeInfos1.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos1.setCreateUser(0);
        rwdeditRefTypeInfos1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos1.setUpdateUser(0);
        rwdeditRefTypeInfos1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setInfos(Arrays.asList(rwdeditRefTypeInfos1));
        final Optional<RwdeditRefType> rwdeditRefType = Optional.of(rwdeditRefType1);
        when(mockRepository.findById("id")).thenReturn(rwdeditRefType);

        // Configure RwdeditRefTypeRepository.save(...).
        final RwdeditRefType rwdeditRefType2 = new RwdeditRefType();
        rwdeditRefType2.setRefKey("refKey");
        rwdeditRefType2.setName("name");
        rwdeditRefType2.setCreateUser(0);
        rwdeditRefType2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setUpdateUser(0);
        rwdeditRefType2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setSeq(0);
        rwdeditRefType2.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos2 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos2.setRefKey("refKey");
        rwdeditRefTypeInfos2.setCode("code");
        rwdeditRefTypeInfos2.setName("name");
        rwdeditRefTypeInfos2.setParentCode("parentCode");
        rwdeditRefTypeInfos2.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos2.setCreateUser(0);
        rwdeditRefTypeInfos2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos2.setUpdateUser(0);
        rwdeditRefTypeInfos2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setInfos(Arrays.asList(rwdeditRefTypeInfos2));
        when(mockRepository.save(any(RwdeditRefType.class))).thenReturn(rwdeditRefType2);

        // Run the test
        final MapResponse result = rwdeditRefTypeServiceUnderTest.create(param);

        // Verify the results
    }

    @Test
    void testCreate_RwdeditRefTypeRepositoryFindByIdReturnsAbsent() {
        // Setup
        final RwdeditRefTypeModel param = new RwdeditRefTypeModel();
        param.setRefKey("refKey");
        param.setName("name");
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setSeq(0);
        param.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setInfos(Arrays.asList(rwdeditRefTypeInfos));

        when(mockRepository.findById("id")).thenReturn(Optional.empty());

        // Configure RwdeditRefTypeRepository.save(...).
        final RwdeditRefType rwdeditRefType = new RwdeditRefType();
        rwdeditRefType.setRefKey("refKey");
        rwdeditRefType.setName("name");
        rwdeditRefType.setCreateUser(0);
        rwdeditRefType.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setUpdateUser(0);
        rwdeditRefType.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setSeq(0);
        rwdeditRefType.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos1 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos1.setRefKey("refKey");
        rwdeditRefTypeInfos1.setCode("code");
        rwdeditRefTypeInfos1.setName("name");
        rwdeditRefTypeInfos1.setParentCode("parentCode");
        rwdeditRefTypeInfos1.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos1.setCreateUser(0);
        rwdeditRefTypeInfos1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos1.setUpdateUser(0);
        rwdeditRefTypeInfos1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setInfos(Arrays.asList(rwdeditRefTypeInfos1));
        when(mockRepository.save(any(RwdeditRefType.class))).thenReturn(rwdeditRefType);

        // Run the test
        final MapResponse result = rwdeditRefTypeServiceUnderTest.create(param);

        // Verify the results
    }

    @Test
    void testUpdate() {
        // Setup
        final RwdeditRefTypeModel param = new RwdeditRefTypeModel();
        param.setRefKey("refKey");
        param.setName("name");
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setSeq(0);
        param.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setInfos(Arrays.asList(rwdeditRefTypeInfos));

        // Configure RwdeditRefTypeRepository.findById(...).
        final RwdeditRefType rwdeditRefType1 = new RwdeditRefType();
        rwdeditRefType1.setRefKey("refKey");
        rwdeditRefType1.setName("name");
        rwdeditRefType1.setCreateUser(0);
        rwdeditRefType1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setUpdateUser(0);
        rwdeditRefType1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setSeq(0);
        rwdeditRefType1.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos1 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos1.setRefKey("refKey");
        rwdeditRefTypeInfos1.setCode("code");
        rwdeditRefTypeInfos1.setName("name");
        rwdeditRefTypeInfos1.setParentCode("parentCode");
        rwdeditRefTypeInfos1.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos1.setCreateUser(0);
        rwdeditRefTypeInfos1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos1.setUpdateUser(0);
        rwdeditRefTypeInfos1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType1.setInfos(Arrays.asList(rwdeditRefTypeInfos1));
        final Optional<RwdeditRefType> rwdeditRefType = Optional.of(rwdeditRefType1);
        when(mockRepository.findById("id")).thenReturn(rwdeditRefType);

        // Configure RwdeditRefTypeRepository.save(...).
        final RwdeditRefType rwdeditRefType2 = new RwdeditRefType();
        rwdeditRefType2.setRefKey("refKey");
        rwdeditRefType2.setName("name");
        rwdeditRefType2.setCreateUser(0);
        rwdeditRefType2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setUpdateUser(0);
        rwdeditRefType2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setSeq(0);
        rwdeditRefType2.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos2 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos2.setRefKey("refKey");
        rwdeditRefTypeInfos2.setCode("code");
        rwdeditRefTypeInfos2.setName("name");
        rwdeditRefTypeInfos2.setParentCode("parentCode");
        rwdeditRefTypeInfos2.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos2.setCreateUser(0);
        rwdeditRefTypeInfos2.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos2.setUpdateUser(0);
        rwdeditRefTypeInfos2.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType2.setInfos(Arrays.asList(rwdeditRefTypeInfos2));
        when(mockRepository.save(any(RwdeditRefType.class))).thenReturn(rwdeditRefType2);

        // Run the test
        final MapResponse result = rwdeditRefTypeServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testUpdate_RwdeditRefTypeRepositoryFindByIdReturnsAbsent() {
        // Setup
        final RwdeditRefTypeModel param = new RwdeditRefTypeModel();
        param.setRefKey("refKey");
        param.setName("name");
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setSeq(0);
        param.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setInfos(Arrays.asList(rwdeditRefTypeInfos));

        when(mockRepository.findById("id")).thenReturn(Optional.empty());

        // Configure RwdeditRefTypeRepository.save(...).
        final RwdeditRefType rwdeditRefType = new RwdeditRefType();
        rwdeditRefType.setRefKey("refKey");
        rwdeditRefType.setName("name");
        rwdeditRefType.setCreateUser(0);
        rwdeditRefType.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setUpdateUser(0);
        rwdeditRefType.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setSeq(0);
        rwdeditRefType.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos1 = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos1.setRefKey("refKey");
        rwdeditRefTypeInfos1.setCode("code");
        rwdeditRefTypeInfos1.setName("name");
        rwdeditRefTypeInfos1.setParentCode("parentCode");
        rwdeditRefTypeInfos1.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos1.setCreateUser(0);
        rwdeditRefTypeInfos1.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos1.setUpdateUser(0);
        rwdeditRefTypeInfos1.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefType.setInfos(Arrays.asList(rwdeditRefTypeInfos1));
        when(mockRepository.save(any(RwdeditRefType.class))).thenReturn(rwdeditRefType);

        // Run the test
        final MapResponse result = rwdeditRefTypeServiceUnderTest.update(param);

        // Verify the results
    }

    @Test
    void testDelete() {
        // Setup
        final RwdeditRefTypeModel param = new RwdeditRefTypeModel();
        param.setRefKey("refKey");
        param.setName("name");
        param.setCreateUser(0);
        param.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setUpdateUser(0);
        param.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setSeq(0);
        param.setShowPosition(0);
        final RwdeditRefTypeInfos rwdeditRefTypeInfos = new RwdeditRefTypeInfos();
        rwdeditRefTypeInfos.setRefKey("refKey");
        rwdeditRefTypeInfos.setCode("code");
        rwdeditRefTypeInfos.setName("name");
        rwdeditRefTypeInfos.setParentCode("parentCode");
        rwdeditRefTypeInfos.setDataSource(new ObjectNode(new JsonNodeFactory(false)));
        rwdeditRefTypeInfos.setCreateUser(0);
        rwdeditRefTypeInfos.setCreateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        rwdeditRefTypeInfos.setUpdateUser(0);
        rwdeditRefTypeInfos.setUpdateTime(new GregorianCalendar(2020, Calendar.JANUARY, 1).getTime());
        param.setInfos(Arrays.asList(rwdeditRefTypeInfos));

        // Run the test
        final MapResponse result = rwdeditRefTypeServiceUnderTest.delete(param);

        // Verify the results
        verify(mockRepository).deleteById("id");
    }
}
